revert_snapshot

Function revert_snapshot 

pub fn revert_snapshot(version_path: &Path, live_path: &Path) -> Result<()>
Revert a file to a previous snapshot version by copying the version file over the live path.